@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker and Matt Lilley
     E-mail:        J.Wielemaker@cs.vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2012-2016, VU University Amsterdam
+    Copyright (c)  2012-2018, VU University Amsterdam
     All rights reserved.
 
     Redistribution and use in source and binary forms, with or without
@@ -73,6 +73,10 @@ The following example lists the entries in an archive:
 
 :- use_foreign_library(foreign(archive4pl)).
 
+%!  archive_open(+Data, -Archive, +Options) is det.
+%
+%   Wrapper around archive_open/4 that opens the archive in read mode.
+
 archive_open(Stream, Archive, Options) :-
     archive_open(Stream, read, Archive, Options).
 
@@ -121,12 +125,12 @@ archive_open(Stream, Archive, Options) :-
 %     multiple times to support multiple formats in read mode.
 %     In write mode, you must supply a single format. If no format
 %     options are provided, =all= is assumed for read mode. Note that
-%     =all= does *not* include =raw=. To open both archive
+%     =all= does *not* include =raw= and =mtree=. To open both archive
 %     and non-archive files, _both_ format(all) and
-%     format(raw) must be specified. Supported values are: =all=,
-%     =7zip=, =ar=, =cab=, =cpio=, =empty=, =gnutar=, =iso9660=,
-%     =lha=, =mtree=, =rar=, =raw=, =tar=, =xar= and =zip=. The
-%     value =all= is default for read.
+%     format(raw) and/or format(mtree) must be specified. Supported
+%     values are: =all=, =7zip=, =ar=, =cab=, =cpio=, =empty=, =gnutar=,
+%     =iso9660=, =lha=, =mtree=, =rar=, =raw=, =tar=, =xar= and =zip=.
+%     The value =all= is default for read.
 %
 %   Note that the actually supported   compression types and formats
 %   may vary depending on the version   and  installation options of
@@ -280,6 +284,9 @@ header_property(permissions(_)).
 %
 %     * remove_prefix(+Prefix)
 %     Strip Prefix from all entries before extracting
+%     * exclude(+ListOfPatterns)
+%     Ignore members that match one of the given patterns.
+%     Patterns are handed to wildcard_match/2.
 %
 %   @error  existence_error(directory, Dir) if Dir does not exist
 %           or is not a directory.
@@ -300,7 +307,8 @@ archive_extract(Archive, Dir, Options) :-
 extract(Archive, Dir, Options) :-
     archive_next_header(Archive, Path),
     !,
-    (   archive_header_property(Archive, filetype(file))
+    (   archive_header_property(Archive, filetype(file)),
+        \+ excluded(Path, Options)
     ->  archive_header_property(Archive, permissions(Perm)),
         (   option(remove_prefix(Remove), Options)
         ->  (   atom_concat(Remove, ExtractPath, Path)
@@ -325,13 +333,22 @@ extract(Archive, Dir, Options) :-
     extract(Archive, Dir, Options).
 extract(_, _, _).
 
+excluded(Path, Options) :-
+    option(exclude(Patterns), Options),
+    split_string(Path, "/", "/", Parts),
+    member(Segment, Parts),
+    Segment \== "",
+    member(Pattern, Patterns),
+    wildcard_match(Pattern, Segment).
+
+
 %!  set_permissions(+Perm:integer, +Target:atom)
 %
 %   Restore the permissions.  Currently only restores the executable
 %   permission.
 
 set_permissions(Perm, Target) :-
-    Perm /\ 0o700 =\= 0,
+    Perm /\ 0o100 =\= 0,
     !,
     '$mark_executable'(Target).
 set_permissions(_, _).
@@ -380,9 +397,9 @@ contents(_, []).
 %       - name(Atom)
 %       Name of the entry.
 %
-%   Note that this predicate can  handle   a  non-archive files as a
-%   pseudo archive holding a single   stream by using archive_open/3
-%   with the options `[format(all), format(raw)]`.
+%   Non-archive files are handled as pseudo-archives that hold a
+%   single stream.  This is implemented by using archive_open/3 with
+%   the options `[format(all),format(raw)]`.
 
 archive_data_stream(Archive, DataStream, Options) :-
     option(meta_data(MetaData), Options, _),
@@ -449,6 +466,12 @@ open_substream(In, Entry, ArchiveMetadata, PipeTailMetadata) :-
 %     Directory and archived files will not have Directory
 %     as leading path. This is to simulate =|-C|= option of
 %     the =tar= program.
+%
+%     * format(+Format)
+%     Write mode supports the following formats: `7zip`, `cpio`,
+%     `gnutar`, `iso9660`, `xar` and `zip`.  Note that a particular
+%     installation may support only a subset of these, depending on
+%     the configuration of `libarchive`.
 
 archive_create(OutputFile, InputFiles, Options) :-
     must_be(list(text), InputFiles),
