@@ -341,7 +341,7 @@ user_agent('SWI-Prolog').
 %   that need to be be processed by the client code.
 %
 %   @param URL is either an atom or string (url) or a list of _parts_.
-
+%
 %               When provided, this list may contain the fields
 %               =scheme=, =user=, =password=, =host=, =port=, =path=
 %               and either =query_string= (whose argument is an atom)
@@ -643,6 +643,7 @@ auth_header(basic(User, Password), _, Header, Out) :-
     format(Out, '~w: Basic ~s\r\n', [Header, Base64Codes]).
 auth_header(bearer(Token), _, Header, Out) :-
     !,
+    debug(http(send_request), "> ~w: Bearer ~w", [Header,Token]),
     format(Out, '~w: Bearer ~w\r\n', [Header, Token]).
 auth_header(Auth, Options, _, Out) :-
     option(url(URL), Options),
@@ -806,9 +807,10 @@ map_error_code(405, permission_error).
 map_error_code(407, permission_error).
 map_error_code(410, existence_error).
 
-redirect_code(301).                     % moved permanently
-redirect_code(302).                     % moved temporary
-redirect_code(303).                     % see also
+redirect_code(301).                     % Moved Permanently
+redirect_code(302).                     % Found (previously "Moved Temporary")
+redirect_code(303).                     % See Other
+redirect_code(307).                     % Temporary Redirect
 
 authenticate_code(401).
 
