@@ -389,6 +389,7 @@ DECL_PLIST(trie);
 DECL_PLIST(tabling);
 DECL_PLIST(mutex);
 DECL_PLIST(zip);
+DECL_PLIST(cbtrace);
 
 void
 initBuildIns(void)
@@ -455,6 +456,7 @@ initBuildIns(void)
   REG_PLIST(tabling);
   REG_PLIST(mutex);
   REG_PLIST(zip);
+  REG_PLIST(cbtrace);
 
 #define LOOKUPPROC(name) \
 	{ GD->procedures.name = lookupProcedure(FUNCTOR_ ## name, m); \
